<?php
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

function formulaires_parametrer_controle_charger_dist($type_controle, $id_auteur, $redirect = '') {

	// Initialisation des valeurs à passer au formulaire
	$valeurs = array(
		'editable'          => false,
		'type_controle'     => $type_controle,
		'_description'      => '',
		'_message_inactif'  => false,
		'_champs_fonction'  => array(),
		'_champs_squelette' => array(),
		'_bouton_execution' => false
	);

	// Récupération des informations sur la type de contrôle
	include_spip('inc/ezcheck_type_controle');
	$configuration_type_controle = type_controle_lire($type_controle);
	if ($configuration_type_controle) {
		// A minima on affichera sa description
		$valeurs['_description'] = typo($configuration_type_controle['description']);

		// On détermine si il faut afficher le message d'inactivité
		$valeurs['_message_inactif'] = (
			($configuration_type_controle['est_etat'] === 'non')
			and ($configuration_type_controle['actif'] !== 'oui')
		);

		if (autoriser('executer', 'typecontrole', $type_controle)) {
			// Paramètres du type de contrôle défini dans son fichier YAML.
			// Cette configuration peut comporter des paramètres de saisie spécifiques dont les valeurs sont ensuite
			// stockées dans le champ 'parametres' de la table 'spip_controles'.
			// On distingue les paramètres de la fonction d'exécution et ceux du squelette.
			// Cette structure de formulaire est générée automatiquement par le plugin Saisies.
			$valeurs['_champs_fonction'] = $configuration_type_controle['parametres']['fonction'];
			$valeurs['_champs_squelette'] = $configuration_type_controle['parametres']['squelette'];

			// Déterminer le nombre d'anomalies encore ouvertes pour le type de contrôle
			include_spip('inc/ezcheck_observation');
			$filtres = array(
				'type_controle' => $type_controle,
				'est_anomalie'  => 'oui',
				'statut'        => 'ouverte',
			);
			$observations = observation_repertorier($filtres, 'id_observation');
			$valeurs['_bouton_execution'] = (count($observations) === 0);

			$valeurs['editable'] = !$valeurs['_message_inactif'];
		}
	}

	return $valeurs;
}

function formulaires_parametrer_controle_verifier_dist($type_controle, $id_auteur, $redirect = '') {
	$erreurs = array();

	// Vérifier les champs correspondant aux paramètres spécifiques du type de contrôle
	include_spip('inc/ezcheck_type_controle');
	$champs = type_controle_lire($type_controle, 'parametres');
	$champs = array_merge($champs['fonction'], $champs['squelette']);

	if ($champs) {
		include_spip('inc/saisies');
		$erreurs = saisies_verifier($champs, false);
	}

	return $erreurs;
}

function formulaires_parametrer_controle_traiter_dist($type_controle, $id_auteur, $redirect = '') {
	$retour = array();

	if (autoriser('executer', 'typecontrole', $type_controle)) {
		// On constitue le tableau des valeurs des paramètres spécifiques du type de contrôle
		include_spip('inc/ezcheck_type_controle');
		$champs = type_controle_lire($type_controle, 'parametres');

		include_spip('inc/saisies_lister');
		$parametres = array();
		if ($champs['fonction']) {
			foreach (saisies_lister_champs($champs['fonction'], false) as $_champ) {
				$parametres['fonction'][$_champ] = _request($_champ);
			}
		}
		if ($champs['squelette']) {
			foreach (saisies_lister_champs($champs['squelette'], false) as $_champ) {
				$parametres['squelette'][$_champ] = _request($_champ);
			}
		}

		// Exécution du type de contrôle avec les paramètres éventuellement saisis
		include_spip('action/executer_type_controle');
		if (type_controle_executer($type_controle, intval($id_auteur), $parametres)) {
			$retour['redirect'] = $redirect;
		} else {
			$retour['message_erreur'] = _T('ezcheck:type_controle_execution_message_erreur');
		}
	}

	return $retour;
}
